==> react-common-bootstrap-1.1.6.tgz: package/form/CustomForm.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useMemo, useState } from 'react';
const DisplayErrorCtx = /*#__PURE__*/React.createContext(false);
const CustomForm = ({
  children,
  formFields = {},
  setFormFields = () => {},
  onSubmit = () => {},
  submitLabel = 'Valider',
  cancelLabel = 'Annuler',
  className = '',
  disabled = false,
  isLoading = false,
  onCancel = null,
  errorMessage = null,
  isFormValid = true,
  displaySubmitError = false,
  hideValidateButton = false,
  ...props
}, ref) => {
  const [displayError, setDisplayError] = useState(false);
  const [submitError, setSubmitError] = useState(null);
  const [isLoadingSubmit, setIsLoadingSubmit] = useState(false);
  const context = useMemo(() => ({
    displayError,
    formFields,
    setFormFields,
    setFormField: (fieldName, value) => setFormFields(prev => ({
      ...prev,
      [fieldName]: value
    }))
  }), [displayError, formFields]);
  const submit = e => {
    e.preventDefault();
    !displayError && setDisplayError(true);
    if (isFormValid) {
      setIsLoadingSubmit(true);
      Promise.resolve(onSubmit(e)).catch(e => (setSubmitError(e.response.data), console.log(e.config.data))).finally(() => setIsLoadingSubmit(false));
    }
  };
  return /*#__PURE__*/React.createElement(DisplayErrorCtx.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("form", _extends({
    onSubmit: submit,
    className: className
  }, props, {
    ref: ref
  }), children, displayError && !isFormValid && errorMessage != null && /*#__PURE__*/React.createElement("p", {
    className: "informations danger"
  }, errorMessage), submitError != null && /*#__PURE__*/React.createElement("p", {
    className: "informations"
  }, "Une erreur est survenue", ' ', displaySubmitError && /*#__PURE__*/React.createElement("span", null, ": ", submitError)), /*#__PURE__*/React.createElement("div", {
    className: "form-buttons-container"
  }, !hideValidateButton && /*#__PURE__*/React.createElement("button", {
    disabled: disabled || isLoading,
    className: `button button-uca-blue spaced-inline ${(disabled || isLoading) && 'disabled'}`
  }, /*#__PURE__*/React.createElement("span", null, submitLabel), isLoading || isLoadingSubmit && /*#__PURE__*/React.createElement("div", {
    className: "spinner-border spinner-border-sm",
    role: "status"
  })), onCancel != null && /*#__PURE__*/React.createElement("button", {
    className: "button button-uca-beige",
    type: "button",
    onClick: onCancel
  }, cancelLabel))));
};
const useFormContext = () => useContext(DisplayErrorCtx);
export { DisplayErrorCtx, useFormContext };
export default /*#__PURE__*/React.forwardRef(CustomForm);

==> react-common-bootstrap-2.0.1.tgz: package/form/CustomForm.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
const DisplayErrorCtx = /*#__PURE__*/React.createContext(false);
const CustomForm = ({
  children,
  onSubmit = () => {},
  submitLabel = 'Valider',
  cancelLabel = 'Annuler',
  className = '',
  disabled = false,
  isLoading = false,
  onCancel = null,
  errorMessage = null,
  isFormValid = true,
  displaySubmitError = false,
  ...props
}, ref) => {
  const [displayError, setDisplayError] = useState(false);
  const [submitError, setSubmitError] = useState(null);
  const [isLoadingSubmit, setIsLoadingSubmit] = useState(false);
  const submit = e => {
    e.preventDefault();
    !displayError && setDisplayError(true);
    if (isFormValid) {
      setIsLoadingSubmit(true);
      Promise.resolve(onSubmit(e)).catch(e => (setSubmitError(e.response.data), console.log(e.config.data))).finally(() => setIsLoadingSubmit(false));
    }
  };
  return /*#__PURE__*/React.createElement(DisplayErrorCtx.Provider, {
    value: displayError
  }, /*#__PURE__*/React.createElement("form", _extends({
    onSubmit: submit,
    className: className
  }, props, {
    ref: ref
  }), children, displayError && !isFormValid && errorMessage != null && /*#__PURE__*/React.createElement("p", {
    className: "informations danger"
  }, errorMessage), submitError != null && /*#__PURE__*/React.createElement("p", {
    className: "informations"
  }, "Une erreur est survenue", ' ', displaySubmitError && /*#__PURE__*/React.createElement("span", null, ": ", submitError)), /*#__PURE__*/React.createElement("div", {
    className: "form-buttons-container"
  }, /*#__PURE__*/React.createElement("button", {
    disabled: disabled || isLoading,
    className: `btn btn-primary flex line spaced-inline ${(disabled || isLoading) && 'disabled'}`
  }, /*#__PURE__*/React.createElement("span", null, submitLabel), isLoading || isLoadingSubmit && /*#__PURE__*/React.createElement("div", {
    className: "spinner-border spinner-border-sm",
    role: "status"
  })), onCancel != null && /*#__PURE__*/React.createElement("button", {
    className: "btn btn-secondary",
    type: "button",
    onClick: onCancel
  }, cancelLabel))));
};
export { DisplayErrorCtx };
export default /*#__PURE__*/React.forwardRef(CustomForm);
